CardFieldPlaceholder class

Placeholder text configuration.

Constructors

CardFieldPlaceholder({String number = '4242 4242 4242 4242', String expiry = 'MM/YY', String cvc = 'CVC', String postalCode = 'ZIP'})
Creates placeholder configuration.
const

Properties

cvc String
CVC placeholder.
final
expiry String
Expiry placeholder.
final
hashCode int
The hash code for this object.
no setterinherited
number String
Card number placeholder.
final
postalCode String
Postal code placeholder.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited