FamCardForm class

A multi-field card input form.

Provides separate inputs for card number, expiry, CVC, and optionally cardholder name and billing address.

FamCardForm(
  style: CardFormStyle.standard,
  enableCardholderName: true,
  enablePostalCode: true,
  onCardChanged: (details) {
    if (details.complete) {
      // Enable submit button
    }
  },
)
Inheritance

Constructors

FamCardForm({Key? key, CardFormStyle style = CardFormStyle.standard, ValueChanged<CardFormDetails>? onCardChanged, ValueChanged<bool>? onFocusChanged, bool enableCardholderName = false, bool enablePostalCode = false, String? countryCode, bool autofocus = false, bool enabled = true, FamTheme? theme, String cardNumberLabel = 'Card number', String expiryLabel = 'Expiry date', String cvcLabel = 'CVC', String cardholderNameLabel = 'Name on card', String postalCodeLabel = 'ZIP / Postal code'})
Creates a card form.
const

Properties

autofocus bool
Whether to autofocus.
final
cardholderNameLabel String
Cardholder name field label.
final
cardNumberLabel String
Card number field label.
final
countryCode String?
Country code for formatting.
final
cvcLabel String
CVC field label.
final
enableCardholderName bool
Whether to show cardholder name field.
final
enabled bool
Whether the form is enabled.
final
enablePostalCode bool
Whether to show postal code field.
final
expiryLabel String
Expiry field label.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCardChanged ValueChanged<CardFormDetails>?
Called when card details change.
final
onFocusChanged ValueChanged<bool>?
Called when focus changes.
final
postalCodeLabel String
Postal code field label.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style CardFormStyle
Form style.
final
theme FamTheme?
Custom theme.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FamCardForm>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited