PaymentSheetCompleted class

Payment was completed successfully.

Inheritance

Constructors

PaymentSheetCompleted({required String payinId, String? cardId})
Creates a completed result.
const

Properties

cardId String?
ID of the registered card (if saved).
final
hashCode int
The hash code for this object.
no setterinherited
payinId String
ID of the created pay-in.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited