PaymentSheetFailed class

Payment failed with an error.

Inheritance

Constructors

PaymentSheetFailed({required Object error, String? localizedMessage})
Creates a failed result.
const

Properties

error Object
The error that occurred.
final
hashCode int
The hash code for this object.
no setterinherited
localizedMessage String?
User-friendly error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited